Crate ironrdp_svc

Crate ironrdp_svc 

IronRDP SVC

IronRDP traits to implement RDP static virtual channels.

This crate is part of the IronRDP project.

Re-exports

pub use ironrdp_pdu as pdu;

Structs

ChannelFlags
Channel control flags, as specified in section 2.2.6.1.1 of MS-RDPBCGR.
StaticChannelSet
A set holding at most one StaticVirtualChannel for any given type implementing SvcProcessor.
StaticVirtualChannel
A static virtual channel.
SvcMessage
Encodable PDU to be sent over a static virtual channel.
SvcProcessorMessages
SVC data to be sent to the server. See SvcMessage for more information. Usually returned by the channel-specific methods.

Enums

CompressionCondition
Defines which compression flag should be sent along the ChannelDef structure (CHANNEL_DEF)

Constants

CHANNEL_CHUNK_LENGTH
The default maximum chunk size for virtual channel data.

Traits

SvcClientProcessor
SvcEncode
Represents a message that, when encoded, forms a complete PDU for a given static virtual channel, sans any Channel PDU Header. In other words, this marker should be applied to a message that is ready to be chunkified (have channel PDU headers added, splitting it into chunks if necessary) and wrapped in MCS, x224, and tpkt headers for sending over the wire.
SvcProcessor
A type that is a Static Virtual Channel
SvcServerProcessor

Functions

client_encode_svc_messages
Encode a vector of SvcMessage in preparation for sending them on the channel_id channel.
make_channel_definition
Builds the ChannelDef structure containing information for this channel.
make_channel_options
Builds the ChannelOptions bitfield to be used in the ChannelDef structure.
server_encode_svc_messages
Encode a vector of SvcMessage in preparation for sending them on the channel_id channel.

Type Aliases

StaticChannelId
The integer type representing a static virtual channel ID.