Re-exports
pub use ironrdp_pdu as pdu;
Structs
- Channel
Flags - Channel control flags, as specified in section 2.2.6.1.1 of MS-RDPBCGR.
- Static
Channel Set - A set holding at most one
StaticVirtualChannelfor any given type implementingSvcProcessor. - Static
Virtual Channel - A static virtual channel.
- SvcMessage
- Encodable PDU to be sent over a static virtual channel.
- SvcProcessor
Messages - SVC data to be sent to the server. See
SvcMessagefor more information. Usually returned by the channel-specific methods.
Enums
- Compression
Condition - Defines which compression flag should be sent along the
ChannelDefstructure (CHANNEL_DEF)
Constants
- CHANNEL_
CHUNK_ LENGTH - The default maximum chunk size for virtual channel data.
Traits
- SvcClient
Processor - SvcEncode
- Represents a message that, when encoded, forms a complete PDU for a given static virtual channel, sans any Channel PDU Header. In other words, this marker should be applied to a message that is ready to be chunkified (have channel PDU headers added, splitting it into chunks if necessary) and wrapped in MCS, x224, and tpkt headers for sending over the wire.
- SvcProcessor
- A type that is a Static Virtual Channel
- SvcServer
Processor
Functions
- client_
encode_ svc_ messages - Encode a vector of
SvcMessagein preparation for sending them on thechannel_idchannel. - make_
channel_ definition - Builds the
ChannelDefstructure containing information for this channel. - make_
channel_ options - Builds the
ChannelOptionsbitfield to be used in theChannelDefstructure. - server_
encode_ svc_ messages - Encode a vector of
SvcMessagein preparation for sending them on thechannel_idchannel.
Type Aliases
- Static
Channel Id - The integer type representing a static virtual channel ID.